\name{ArrayAndMatrix-class}
\docType{class}
\alias{ArrayAndMatrix-class}
\alias{RawMatrix-class}
\alias{CharMatrix-class}
\alias{LogicalMatrix-class}
\alias{IntegerMatrix-class}
\alias{NumericMatrix-class}
\alias{ComplexMatrix-class}
\alias{RawArray-class}
\alias{CharArray-class}
\alias{LogicalArray-class}
\alias{IntegerArray-class}
\alias{NumericArray-class}
\alias{ComplexArray-class}

\title{Class "NumericMatrix" and friends}
\description{
  Classes providing \code{\link{matrix}} and \code{\link{array}}
  functionality, but allowing stronger type specification, e.g.,
  \code{NumericMatrix} is a \code{matrix} whose members must be of type
  "numeric". A "matrix" is two-dimensional; an "array" is any
  dimensions, but R treats two-dimensional arrays as "matrix" and
  one-dimensional arrays as "vector" so "XxxArray" is most useful for
  specifying arrays with greater than 2 dimensions.

  Available classes are "RawMatrix" "CharMatrix" "LogicalMatrix"
  "IntegerMatrix" "NumericMatrix" "ComplexMatrix" "RawArray" "CharArray"
  "LogicalArray" "IntegerArray" "NumericArray" "ComplexArray".
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("NumericMatrix",
...)}.  To create an instance from an existing, untyped, "matrix" or
"array", use forms like \code{new("NumericMatrix", m)} or unclass and
update the \code{mode} of the object. See examples for additional
detail.
}
\section{Slots}{None.}
\section{Extends}{
Class \code{"matrix"}, from data part.
Class \code{"structure"}, by class "matrix", distance 2.
Class \code{"array"}, by class "matrix", distance 2.
Class \code{"vector"}, by class "matrix", distance 3, with explicit coerce.
Class \code{"vector"}, by class "matrix", distance 4, with explicit coerce.
}
\section{Methods}{Use "NumericMatrix" and friends as replacements for "matrix" or "array".}
\author{Martin Morgan <mtmorgan@fhcrc.rog}
\examples{
## creating an empty instance
obj <- new("ComplexMatrix")
obj
mode(obj)
## Converting between array and typed Array
new("RawArray", array(raw(), dim=c(5,2,3)))

## Converting between types
obj <- new("NumericMatrix", matrix(numeric()))
obj <- unclass(obj)                     # retrieve underlying matrix
mode(obj) <- "raw"
obj <- new("RawMatrix", obj)
validObject(obj)
obj
}
\keyword{classes}
